#
# This is a Shiny web application. You can run the application by clicking
# the 'Run App' button above.
#
# Find out more about building applications with Shiny here:
#
#    http://shiny.rstudio.com/
#

library(shiny)
library(shinydashboard)
library(shinyMobile)
library(shinythemes)
library(data.table)
library(dplyr)
library(ggplot2)


ui<-dashboardPage(
    
    dashboardHeader(title = em(h5(strong('Identification of distal metastasis of gastric cancer'))),
                    titleWidth = 300),
    dashboardSidebar(width = 300,
                     sidebarMenu(
                         menuItem(strong("About"), tabName = 'homepage', icon = icon('home')),
                         menuItem(strong('classifier'), tabName = 'gallery', icon = icon('book'),
                                  menuSubItem(p('Data treatments'), tabName = 'Dtreat'))
                     )),
    dashboardBody(
        
        tabItems(    
            tabItem(tabName = 'homepage',
                    fluidPage(
                        box(
                            title = h2(strong("数据挖掘期末作业")),
                            width = 500,
                            column(
                                img(src="xiaoxiong.jpg", 
                                    height = 200, width = 150),
                                width = 5
                            ),
                            column(
                                h3(strong('胃癌远端转移分类器')),
                                p('识别胃癌远端和非远端转移'),
                                p('2022/1/6'),
                                h5(strong('组员:叶文海,马媛媛,瞿颖,陈沛言')),
                                a(h4(strong('指导老师:严海丹')),href="https://gic.fjmu.edu.cn/2017/0713/c4338a69301/page.htm"),
                                width = 6
                            ),
                        )
                    )
            ),
            tabItem(tabName = 'Dtreat',
                    fluidPage(
                        
                        box(title = 'Input',
                            status = 'warning',
                            fileInput('SOURCE', label = 'gene expression profile',
                                      width = 1000),
                            
                            box(title = 'Output',
                                status = 'warning',
                                tableOutput('table'),
                                width = 1000),
                            width = 100,
                            solidHeader = TRUE
                        )
                    )
            )
        )
        
    ),
    
    skin = 'red'
    
)


server<-function(input, output) {
    
    
    output$table<-renderTable({
        load("randomforest.Rdata")
        file<-read.csv(input$SOURCE$datapath)
        row.names(file)<-file[,1]
        file<-file[,-1]
        file<-t(file)
        c<-apply(file,1,mean)
        for (i in 1:nrow(file)){
            for (j in 1:ncol(file)){
                if (file[i,j] >=c[i] ){
                    file[i,j]<-1
                }
                else{
                    file[i,j]<-0
                }
            }
        }
        predicts <- predict(randomForestFit,file)
        samples<-row.names(file)
        predicts<-as.data.frame(predicts)
        samples<-as.data.frame(samples)
        ddata<-cbind(samples,predicts)
    })
    
}










shinyApp(ui = ui, server = server)
